@@ -77,15 +77,26 @@ namespace giac {
   static pthread_mutex_t * pari_mutex_ptr = 0;
 #endif
 
+#if PARI_VERSION_CODE >= PARI_VERSION(2,8,0)
+#define PARI_DYNAMIC_STACK
+#endif
+
   static map<string,entree *> pari_function_table;
   static void do_giac_pari_init(long maxprime){
+#ifdef PARI_DYNAMIC_STACK
+    long pari_mem_size=512000;
+#else
     long pari_mem_size=64000000;
+#endif
     if (getenv("PARI_SIZE")){
       string pari_size_s(getenv("PARI_SIZE"));
       pari_mem_size= atoi(pari_size_s.c_str());
     }
     // do not initialize INIT_JMP so that PARI error do not exit
     pari_init_opts(pari_mem_size,maxprime,INIT_SIGm | INIT_DFTm);
+#ifdef PARI_DYNAMIC_STACK
+    paristack_alloc(pari_mem_size, (1<<30)); // pari 2.8
+#endif
     entree * ptr=functions_basic;
     for (;ptr->name;++ptr){
       pari_function_table[ptr->name]=ptr;
@@ -275,6 +286,9 @@ namespace giac {
   }
 
   gen GEN2gen(const GEN & G,const vecteur & vars){
+#ifdef EMCC
+    return default2gen(G);
+#endif
     switch (typ(G)){
     case t_INT:
       return t_INT2gen(G);
@@ -819,6 +833,11 @@ namespace giac {
 	return undef;
       } 
     }
+#endif
+#ifdef EMCC
+    parse_all=true; 
+    // otherwise fibonacci or lngamma do not work, probably because of the 'L'
+    // conversion (long argument expected) or precision (same)
 #endif
     if (!parse_all && v[0].type==_STRNG) {
       string vstr=*v[0]._STRNGptr;
@@ -1099,8 +1118,12 @@ namespace giac {
     int prec=decimal_digits(contextptr);
     if (prec<30)
       prec=30;
+#if 0
     GEN nf=nfinit0(Pmin,0,prec);
     tmp=GEN2gen(nffactor(nf,P),lv);
+#else
+    tmp=GEN2gen(nffactor(Pmin,P),lv);
+#endif
     avma=av;
     PARI_stack_limit=save_pari_stack_limit;
 #ifdef HAVE_LIBPTHREAD
@@ -1138,7 +1161,6 @@ namespace giac {
     return true;
   }
   
-
 #ifndef NO_NAMESPACE_GIAC
 }
 #endif // ndef NO_NAMESPACE_GIAC
@@ -1218,6 +1240,7 @@ namespace giac {
   static define_unary_function_eval (__pari_unlock,&giac::_pari,_pari_unlock_s);
   define_unary_function_ptr5( at_pari_unlock ,alias_at_pari_unlock,&__pari_unlock,_QUOTE_ARGUMENTS,true);
 
+
 #ifndef NO_NAMESPACE_GIAC
 }
 #endif // ndef NO_NAMESPACE_GIAC
